@@ -11,17 +11,11 @@ floating-point arithmetic.
   Reprinted 1996, pp.  889.
 """
 
-from __future__ import division, print_function, absolute_import, unicode_literals
-
 # Standard libraries.
 import math
+from functools import lru_cache
 
-try:
-    from functools import lru_cache
-except ImportError:
-    from backports.functools_lru_cache import lru_cache
-
-__date__ = "2020/06/13 17:49:10 hoel"
+__date__ = "2021/12/11 17:49:36 hoel"
 __author__ = "Berthold Höllmann"
 __copyright__ = "Copyright © 1999, 2000,2018 by Berthold Höllmann"
 __credits__ = ["Berthold Höllmann"]
@@ -31,61 +25,60 @@ __email__ = "bhoel@starship.python.net"
 
 def machar():
     """
-Determines and returns machine-specific parameters affecting
-floating-point arithmetic. Returned values include:
+    Determines and returns machine-specific parameters affecting
+    floating-point arithmetic. Returned values include:
 
-    ``ibeta``  -- The radix in which numbers are represented, almost
-                  always 2, but occasionally 16, or even 10
+        ``ibeta``  -- The radix in which numbers are represented, almost
+                      always 2, but occasionally 16, or even 10
 
-    ``it``     -- The number of base-``ibeta`` digits in the floating point
-                  mantissa
+        ``it``     -- The number of base-``ibeta`` digits in the floating point
+                      mantissa
 
-    ``machep`` -- Is the exponent of the smallest (mos negative) power if
-                  ``ibeta`` that, added to 1.0 gives something different
-                  from 1.0.
+        ``machep`` -- Is the exponent of the smallest (mos negative) power if
+                      ``ibeta`` that, added to 1.0 gives something different
+                      from 1.0.
 
-    ``eps``    -- Is the floating-point number ``ibeta`` ** ``machdep``, loosly
-                  referred to as the *floating-point precision*.
+        ``eps``    -- Is the floating-point number ``ibeta`` ** ``machdep``, loosly
+                      referred to as the *floating-point precision*.
 
-    ``negep``  -- Is the exponenet of the smalles power of ``ibeta`` that,
-                subtracted from 1.0, gives something different from 1.0.
+        ``negep``  -- Is the exponenet of the smalles power of ``ibeta`` that,
+                    subtracted from 1.0, gives something different from 1.0.
 
-    ``epsneg`` -- Is ``ibeta`` ** ``negep``, another way of defining
-                floating-point precision. Not infrequently ``epsneg`` is
-                0.5 times ``eps``; occasionally ``eps`` and ``epsneg`` are
-                equal.
+        ``epsneg`` -- Is ``ibeta`` ** ``negep``, another way of defining
+                    floating-point precision. Not infrequently ``epsneg`` is
+                    0.5 times ``eps``; occasionally ``eps`` and ``epsneg`` are
+                    equal.
 
-    ``iexp``   -- Is the number of bits in the exponent (including its
-                sign or bias)
+        ``iexp``   -- Is the number of bits in the exponent (including its
+                    sign or bias)
 
-    ``minexp`` -- Is the smallest (most negative) power if ``ibeta``
-                consistent with there no leading zeros in the mantissa.
+        ``minexp`` -- Is the smallest (most negative) power if ``ibeta``
+                    consistent with there no leading zeros in the mantissa.
 
-    ``xmin``   -- Is the floating-point number ``ibeta`` ** ``minexp``, generally
-                the smallest (in magnitude) usable floating value
+        ``xmin``   -- Is the floating-point number ``ibeta`` ** ``minexp``, generally
+                    the smallest (in magnitude) usable floating value
 
-    ``maxexp`` -- Is the smallest (positive) power of ``ibeta`` that causes
-                overflow.
+        ``maxexp`` -- Is the smallest (positive) power of ``ibeta`` that causes
+                    overflow.
 
-    ``xmax``   -- Is (1 - ``epsneg``) x ``ibeta`` ** ``maxexp``, generally the largest
-                (in magnitude) usable floating value.
+        ``xmax``   -- Is (1 - ``epsneg``) x ``ibeta`` ** ``maxexp``, generally the largest
+                    (in magnitude) usable floating value.
 
-    ``irnd``   -- Returns a code in the range 0...5, giving information on
-                what kind of rounding is done in addition, and on how
-                underflow is handled.
+        ``irnd``   -- Returns a code in the range 0...5, giving information on
+                    what kind of rounding is done in addition, and on how
+                    underflow is handled.
 
-                If ``irnd`` returns 2 or 5, then your computer is
-                compilant with the IEEE standard for rounding. If it
-                returns 1 or 4, then it is doing some kind of rounding,
-                but not the IEEE standard. If ``irnd`` returns 0 or 3,
-                then it is truncating the result, not rounding it.
+                    If ``irnd`` returns 2 or 5, then your computer is
+                    compilant with the IEEE standard for rounding. If it
+                    returns 1 or 4, then it is doing some kind of rounding,
+                    but not the IEEE standard. If ``irnd`` returns 0 or 3,
+                    then it is truncating the result, not rounding it.
 
-    ``ngrd``   -- Is the number of *guard digits* used when truncating
-                the ploduct of two mantissas to fit the representation
+        ``ngrd``   -- Is the number of *guard digits* used when truncating
+                    the ploduct of two mantissas to fit the representation
 
-This is taken from "NUMERICAL RECIPES in C", second edition,
-Reprinted 1996.
-"""
+    This is taken from "NUMERICAL RECIPES in C", second edition,
+    Reprinted 1996."""
     one = float(1)
     two = one + one
     zero = one - one
