@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 """Tests for `berhoel.helper`.
 """
-from __future__ import division, print_function, absolute_import, unicode_literals
 
 # Standard libraries.
 import time
+from pathlib import Path
 
 # Third party libraries.
 import toml
@@ -13,12 +13,7 @@ import pytest
 
 from berhoel import helper
 
-try:
-    from pathlib import Path
-except ImportError:
-    from pathlib2 import Path
-
-__date__ = "2020/05/09 12:49:50 hoel"
+__date__ = "2021/12/11 17:50:08 hoel"
 __author__ = "Berthold Höllmann"
 __copyright__ = "Copyright © 2020 by Berthold Höllmann"
 __credits__ = ["Berthold Höllmann"]
@@ -58,6 +53,15 @@ def test_swirl(capsys):
         assert res.out == "{}\r".format(expected)
 
 
+def test_swirl_dots(capsys):
+    "Test swirler with (braille) dots."
+    swirl = helper.swirl(helper.SwirlSelect.DOTS)
+    for expected in "⠇⡆⣄⣠⢰⠸⠙⠋":
+        next(swirl)
+        res = capsys.readouterr()
+        assert res.out == "{}\r".format(expected)
+
+
 def test_count_with_message_1(capsys):
     "Test counter with life message."
     count = helper.count_with_msg()
