@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 """Testing `berhoel.helper.machar`
 """
-from __future__ import division, print_function, absolute_import, unicode_literals
+
 from berhoel.helper import machar
 
-__date__ = "0000/00/00 00:00:00 xxx"
+__date__ = "2021/12/11 17:50:51 hoel"
 __author__ = "Berthold Höllmann"
 __copyright__ = "Copyright © 2020 by Berthold Höllmann"
 __credits__ = ["Berthold Höllmann"]
